from ._distutils._modified import (
    newer as newer,
    newer_group as newer_group,
    newer_pairwise as newer_pairwise,
    newer_pairwise_group as newer_pairwise_group,
)

__all__ = ["newer", "newer_pairwise", "newer_group", "newer_pairwise_group"]
